@@ -15,6 +15,7 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 import errno
+from functools import partial
 import os
 import re
 import stat
@@ -25,8 +26,6 @@ from typing import Dict, List
 
 from .lazy_import import lazy_import
 lazy_import(globals(), """
-from datetime import datetime
-import getpass
 import locale
 import ntpath
 import posixpath
@@ -102,12 +101,12 @@ def chmod_if_possible(filename, mode):
         # It is probably faster to just do the chmod, rather than
         # doing a stat, and then trying to compare
         os.chmod(filename, mode)
-    except (IOError, OSError) as e:
+    except OSError as e:
         # Permission/access denied seems to commonly happen on smbfs; there's
         # probably no point warning about it.
         # <https://bugs.launchpad.net/bzr/+bug/606537>
         if getattr(e, 'errno') in (errno.EPERM, errno.EACCES):
-            trace.mutter("ignore error on chmod of %r: %r" % (
+            trace.mutter("ignore error on chmod of {!r}: {!r}".format(
                 filename, e))
             return
         raise
@@ -233,7 +232,7 @@ def fancy_rename(old, new, rename_func, unlink_func):
         rename_func(new, tmp_name)
     except NoSuchFile:
         pass
-    except IOError as e:
+    except OSError as e:
         # RBC 20060103 abstraction leakage: the paramiko SFTP clients rename
         # function raises an IOError with errno is None when a rename fails.
         # This then gets caught here.
@@ -252,7 +251,7 @@ def fancy_rename(old, new, rename_func, unlink_func):
         # not be set.
         rename_func(old, new)
         success = True
-    except (IOError, OSError) as e:
+    except OSError as e:
         # source and target may be aliases of each other (e.g. on a
         # case-insensitive filesystem), so we may have accidentally renamed
         # source by when we tried to rename target
@@ -273,22 +272,6 @@ def fancy_rename(old, new, rename_func, unlink_func):
                 rename_func(tmp_name, new)
 
 
-# In Python 2.4.2 and older, os.path.abspath and os.path.realpath
-# choke on a Unicode string containing a relative path if
-# os.getcwd() returns a non-sys.getdefaultencoding()-encoded
-# string.
-def _posix_abspath(path):
-    # jam 20060426 rather than encoding to fsencoding
-    # copy posixpath.abspath, but use os.getcwdu instead
-    if not posixpath.isabs(path):
-        path = posixpath.join(getcwd(), path)
-    return _posix_normpath(path)
-
-
-def _posix_realpath(path):
-    return os.fsdecode(posixpath.realpath(os.fsencode(path)))
-
-
 def _posix_normpath(path):
     path = posixpath.normpath(path)
     # Bug 861008: posixpath.normpath() returns a path normalized according to
@@ -304,17 +287,6 @@ def _posix_normpath(path):
     return path
 
 
-def _posix_get_home_dir(fsdecode=os.fsdecode):
-    """Get the home directory of the current user as a unicode path"""
-    path = posixpath.expanduser("~")
-    return os.fsdecode(path)
-
-
-def _posix_getuser_unicode():
-    """Get username from environment or password database as unicode"""
-    return getpass.getuser()
-
-
 def _win32_fixdrive(path):
     """Force drive letters to be consistent.
 
@@ -353,7 +325,7 @@ def _win32_normpath(path):
 
 
 def _win32_getcwd():
-    return _win32_fixdrive(_win32_fix_separators(_getcwd()))
+    return _win32_fixdrive(_win32_fix_separators(os.getcwd()))
 
 
 def _win32_rename(old, new):
@@ -375,7 +347,7 @@ def _win32_rename(old, new):
 
 
 def _mac_getcwd():
-    return unicodedata.normalize('NFC', _getcwd())
+    return unicodedata.normalize('NFC', os.getcwd())
 
 
 def _rename_wrap_exception(rename_func):
@@ -399,21 +371,22 @@ def _rename_wrap_exception(rename_func):
     return _rename_wrapper
 
 
-_getcwd = os.getcwd
-
-
 # Default rename wraps os.rename()
 rename = _rename_wrap_exception(os.rename)
 
 # Default is to just use the python builtins, but these can be rebound on
 # particular platforms.
-abspath = _posix_abspath
-realpath = _posix_realpath
+abspath = os.path.abspath
+realpath = os.path.realpath
 pathjoin = os.path.join
 normpath = _posix_normpath
-_get_home_dir = _posix_get_home_dir
-getuser_unicode = _posix_getuser_unicode
-getcwd = _getcwd
+_get_home_dir = partial(os.path.expanduser, '~')
+
+def getuser_unicode():
+    import getpass
+    return getpass.getuser()
+
+getcwd = os.getcwd
 dirname = os.path.dirname
 basename = os.path.basename
 split = os.path.split
@@ -766,6 +739,7 @@ def compare_files(a, b):
 
 def local_time_offset(t=None):
     """Return offset of local zone from GMT, either at present or at time t."""
+    from datetime import datetime
     if t is None:
         t = time.time()
     offset = datetime.fromtimestamp(t) - datetime.utcfromtimestamp(t)
@@ -1081,7 +1055,7 @@ def _split_lines(s):
 
     This supports Unicode or plain string objects.
     """
-    nl = b'\n' if isinstance(s, bytes) else u'\n'
+    nl = b'\n' if isinstance(s, bytes) else '\n'
     lines = s.split(nl)
     result = [line + nl for line in lines[:-1]]
     if lines[-1]:
@@ -1100,7 +1074,7 @@ def link_or_copy(src, dest):
         return
     try:
         os.link(src, dest)
-    except (OSError, IOError) as e:
+    except OSError as e:
         if e.errno != errno.EXDEV:
             raise
         shutil.copyfile(src, dest)
@@ -1113,12 +1087,12 @@ def delete_any(path):
     """
     try:
         _delete_file_or_dir(path)
-    except (OSError, IOError) as e:
+    except OSError as e:
         if e.errno in (errno.EPERM, errno.EACCES):
             # make writable and try again
             try:
                 make_writable(path)
-            except (OSError, IOError):
+            except OSError:
                 pass
             _delete_file_or_dir(path)
         else:
@@ -1263,7 +1237,7 @@ def _cicp_canonical_relpath(base, path):
     for bit in bit_iter:
         lbit = bit.lower()
         try:
-            next_entries = scandir(current)
+            next_entries = os.scandir(current)
         except OSError:  # enoent, eperm, etc
             # We can't find this in the filesystem, so just append the
             # remaining bits.
@@ -1535,7 +1509,7 @@ def _ioctl_terminal_size(width, height):
         s = struct.pack('HHHH', 0, 0, 0, 0)
         x = fcntl.ioctl(1, termios.TIOCGWINSZ, s)
         height, width = struct.unpack('HHHH', x)[0:2]
-    except (IOError, AttributeError):
+    except (OSError, AttributeError):
         pass
     return width, height
 
@@ -1642,40 +1616,6 @@ def check_legal_path(path):
 _WIN32_ERROR_DIRECTORY = 267  # Similar to errno.ENOTDIR
 
 
-try:
-    scandir = os.scandir
-except AttributeError:  # Python < 3
-    lazy_import(globals(), """\
-from scandir import scandir
-""")
-
-
-def _is_error_enotdir(e):
-    """Check if this exception represents ENOTDIR.
-
-    Unfortunately, python is very inconsistent about the exception
-    here. The cases are:
-      1) Linux, Mac OSX all versions seem to set errno == ENOTDIR
-      2) Windows, Python2.4, uses errno == ERROR_DIRECTORY (267)
-         which is the windows error code.
-      3) Windows, Python2.5 uses errno == EINVAL and
-         winerror == ERROR_DIRECTORY
-
-    :param e: An Exception object (expected to be OSError with an errno
-        attribute, but we should be able to cope with anything)
-    :return: True if this represents an ENOTDIR error. False otherwise.
-    """
-    en = getattr(e, 'errno', None)
-    if (en == errno.ENOTDIR or
-        (sys.platform == 'win32' and
-            (en == _WIN32_ERROR_DIRECTORY or
-             (en == errno.EINVAL
-              and getattr(e, 'winerror', None) == _WIN32_ERROR_DIRECTORY)
-             ))):
-        return True
-    return False
-
-
 def walkdirs(top, prefix="", fsdecode=os.fsdecode):
     """Yield data about all the directories in a tree.
 
@@ -1715,21 +1655,20 @@ def walkdirs(top, prefix="", fsdecode=os.fsdecode):
         # 0 - relpath, 1- basename, 2- kind, 3- stat, 4-toppath
         relroot, _, _, _, top = pending.pop()
         if relroot:
-            relprefix = relroot + u'/'
+            relprefix = relroot + '/'
         else:
             relprefix = ''
-        top_slash = top + u'/'
+        top_slash = top + '/'
 
         dirblock = []
         try:
-            for entry in scandir(top):
+            for entry in os.scandir(top):
                 name = fsdecode(entry.name)
                 statvalue = entry.stat(follow_symlinks=False)
                 kind = file_kind_from_stat_mode(statvalue.st_mode)
                 dirblock.append((relprefix + name, name, kind, statvalue, entry.path))
-        except OSError as e:
-            if not _is_error_enotdir(e):
-                raise
+        except NotADirectoryError as e:
+            pass
         dirblock.sort()
         yield (relroot, top), dirblock
 
@@ -1737,7 +1676,7 @@ def walkdirs(top, prefix="", fsdecode=os.fsdecode):
         pending.extend(d for d in reversed(dirblock) if d[2] == _directory)
 
 
-class DirReader(object):
+class DirReader:
     """An interface for reading directories."""
 
     def top_prefix_to_starting_dir(self, top, prefix=""):
@@ -1853,7 +1792,7 @@ class UnicodeDirReader(DirReader):
 
         dirblock = []
         append = dirblock.append
-        for entry in scandir(safe_utf8(top)):
+        for entry in os.scandir(safe_utf8(top)):
             name = os.fsdecode(entry.name)
             abspath = top_slash + name
             name_utf8 = _utf8_encode(name, 'surrogateescape')[0]
@@ -2037,7 +1976,7 @@ def read_bytes_from_socket(sock, report_activity=None,
     while True:
         try:
             data = sock.recv(max_read_size)
-        except socket.error as e:
+        except OSError as e:
             eno = e.args[0]
             if eno in _end_of_stream_errors:
                 # The connection was closed by the other side.  Callers expect
@@ -2091,7 +2030,7 @@ def send_all(sock, bytes, report_activity=None):
     while sent_total < byte_count:
         try:
             sent = sock.send(view[sent_total:sent_total + MAX_SOCKET_CHUNK])
-        except (socket.error, IOError) as e:
+        except OSError as e:
             if e.args[0] in _end_of_stream_errors:
                 raise errors.ConnectionReset(
                     "Error trying to write to socket", e)
@@ -2122,7 +2061,7 @@ def connect_socket(address):
             sock.connect(sa)
             return sock
 
-        except socket.error as e:
+        except OSError as e:
             err = e
             # 'err' is now the most recent error
             if sock is not None:
@@ -2174,7 +2113,7 @@ def resource_string(package, resource_name):
     base = dirname(breezy.__file__)
     if getattr(sys, 'frozen', None):    # bzr.exe
         base = abspath(pathjoin(base, '..', '..'))
-    with open(pathjoin(base, resource_relpath), "rt") as f:
+    with open(pathjoin(base, resource_relpath)) as f:
         return f.read()
 
 
@@ -2228,7 +2167,7 @@ def until_no_eintr(f, *a, **kw):
     while True:
         try:
             return f(*a, **kw)
-        except (IOError, OSError) as e:
+        except OSError as e:
             if e.errno == errno.EINTR:
                 continue
             raise
@@ -2302,7 +2241,7 @@ def local_concurrency(use_cache=True):
             # multiprocessing.cpu_count() isn't implemented on all platforms
             try:
                 concurrency = _local_concurrency()
-            except (OSError, IOError):
+            except OSError:
                 pass
     try:
         concurrency = int(concurrency)
@@ -2438,12 +2377,12 @@ def fdatasync(fileno):
     if fn is not None:
         try:
             fn(fileno)
-        except IOError as e:
+        except OSError as e:
             # See bug #1075108, on some platforms fdatasync exists, but can
             # raise ENOTSUP. However, we are calling fdatasync to be helpful
             # and reduce the chance of corruption-on-powerloss situations. It
             # is not a mandatory call, so it is ok to suppress failures.
-            trace.mutter("ignoring error calling fdatasync: %s" % (e,))
+            trace.mutter("ignoring error calling fdatasync: {}".format(e))
             if getattr(e, 'errno', None) not in _fdatasync_ignored:
                 raise
 
@@ -2479,7 +2418,7 @@ def read_mtab(path):
             yield cols[1], cols[2].decode('ascii', 'replace')
 
 
-class FilesystemFinder(object):
+class FilesystemFinder:
     """Find the filesystem for a particular path."""
 
     def find(self, path):
@@ -2507,7 +2446,7 @@ class MtabFilesystemFinder(FilesystemFinder):
         # we need to re-read it.
         try:
             return cls(read_mtab(cls.MTAB_PATH))
-        except EnvironmentError as e:
+        except OSError as e:
             trace.mutter('Unable to read mtab: %s', e)
             return cls([])
 
