@@ -21,6 +21,7 @@ import json
 import os
 import re
 import time
+from typing import Optional
 
 from ... import (
     bedding,
@@ -49,6 +50,13 @@ from ...forge import (
 
 _DEFAULT_FILES = ['/etc/python-gitlab.cfg', '~/.python-gitlab.cfg']
 DEFAULT_PAGE_SIZE = 50
+DEFAULT_PREFERRED_SCHEMES = ["ssh", "http"]
+SCHEME_MAP = {
+    'git+ssh': 'ssh_url_to_repo',
+    'ssh': 'ssh_url_to_repo',
+    'http': 'http_url_to_repo',
+    'https': 'http_url_to_repo',
+}
 
 
 def mp_status_to_status(status):
@@ -174,13 +182,11 @@ def iter_tokens():
         [os.path.expanduser(p) for p in _DEFAULT_FILES] +
         # backwards compatibility
         [os.path.join(bedding.config_dir(), 'gitlab.conf')])
-    for name, section in config.items():
-        yield name, section
+    yield from config.items()
 
     from breezy.config import AuthenticationConfig
     auth_config = AuthenticationConfig()
-    for name, section in auth_config._get_config().iteritems():
-        yield name, section
+    yield from auth_config._get_config().iteritems()
 
 
 def get_credentials_by_url(url):
@@ -240,6 +246,8 @@ def _unexpected_status(path, response):
 
 class GitLabMergeProposal(MergeProposal):
 
+    supports_auto_merge = True
+
     def __init__(self, gl, mr):
         self.gl = gl
         self._mr = mr
@@ -254,7 +262,7 @@ class GitLabMergeProposal(MergeProposal):
                 self._mr['target_project_id'])
 
     def __repr__(self):
-        return "<%s at %r>" % (type(self).__name__, self._mr['web_url'])
+        return "<{} at {!r}>".format(type(self).__name__, self._mr['web_url'])
 
     @property
     def url(self):
@@ -267,7 +275,17 @@ class GitLabMergeProposal(MergeProposal):
         return self._mr['description']
 
     def set_description(self, description):
-        self._update(description=description, title=determine_title(description))
+        try:
+            self._update(description=description)
+        except errors.UnexpectedHttpStatus as e:
+            # HACK: Some versions of GitLab apply the changes but fail with a 500
+            # This appears to happen at least with version 15.5.6
+            if e.code != 500:
+                raise
+            self._mr = self.gl._get_merge_request(
+                self._mr['project_id'], self._mr['iid'])
+            if self._mr['description'] != description:
+                raise
 
     def get_commit_message(self):
         return self._mr.get('merge_commit_message')
@@ -281,15 +299,21 @@ class GitLabMergeProposal(MergeProposal):
     def set_title(self, title):
         self._update(title=title)
 
-    def _branch_url_from_project(self, project_id, branch_name):
+    def _branch_url_from_project(self, project_id, branch_name, *, preferred_schemes=None):
         if project_id is None:
             return None
         project = self.gl._get_project(project_id)
-        return gitlab_url_to_bzr_url(project['http_url_to_repo'], branch_name)
+        if preferred_schemes is None:
+            preferred_schemes = DEFAULT_PREFERRED_SCHEMES
+        for scheme in preferred_schemes:
+            if scheme in SCHEME_MAP:
+                return gitlab_url_to_bzr_url(project[SCHEME_MAP[scheme]], branch_name)
+        raise KeyError
 
-    def get_source_branch_url(self):
+    def get_source_branch_url(self, *, preferred_schemes=None):
         return self._branch_url_from_project(
-            self._mr['source_project_id'], self._mr['source_branch'])
+            self._mr['source_project_id'], self._mr['source_branch'],
+            preferred_schemes=preferred_schemes)
 
     def get_source_revision(self):
         from breezy.git.mapping import default_mapping
@@ -298,9 +322,10 @@ class GitLabMergeProposal(MergeProposal):
             return None
         return default_mapping.revision_id_foreign_to_bzr(sha.encode('ascii'))
 
-    def get_target_branch_url(self):
+    def get_target_branch_url(self, *, preferred_schemes=None):
         return self._branch_url_from_project(
-            self._mr['target_project_id'], self._mr['target_branch'])
+            self._mr['target_project_id'], self._mr['target_branch'],
+            preferred_schemes=preferred_schemes)
 
     def set_target_branch_name(self, name):
         self._update(branch=name)
@@ -327,11 +352,12 @@ class GitLabMergeProposal(MergeProposal):
     def close(self):
         self._update(state_event='close')
 
-    def merge(self, commit_message=None):
+    def merge(self, commit_message=None, auto=False):
         # https://docs.gitlab.com/ee/api/merge_requests.html#accept-mr
         ret = self.gl._merge_mr(
             self._mr['project_id'], self._mr['iid'],
-            kwargs={"merge_commit_message": commit_message})
+            kwargs={"merge_commit_message": commit_message,
+                    "merge_when_pipeline_succeeds": auto})
         self._mr.update(ret)
 
     def can_be_merged(self):
@@ -536,8 +562,7 @@ class GitLab(Forge):
             if response.status != 200:
                 _unexpected_status(path, response)
             page = response.getheader("X-Next-Page")
-            for entry in json.loads(response.data):
-                yield entry
+            yield from json.loads(response.data)
 
     def _list_merge_requests(self, author=None, project=None, state=None):
         if project is not None:
@@ -566,7 +591,7 @@ class GitLab(Forge):
         return self._list_paged(path, parameters, per_page=DEFAULT_PAGE_SIZE)
 
     def _update_merge_request(self, project_id, iid, mr):
-        path = 'projects/%s/merge_requests/%s' % (
+        path = 'projects/{}/merge_requests/{}'.format(
             urlutils.quote(str(project_id), ''), iid)
         response = self._api_request('PUT', path, fields=mr)
         if response.status == 200:
@@ -578,7 +603,7 @@ class GitLab(Forge):
         _unexpected_status(path, response)
 
     def _merge_mr(self, project_id, iid, kwargs):
-        path = 'projects/%s/merge_requests/%s/merge' % (
+        path = 'projects/{}/merge_requests/{}/merge'.format(
             urlutils.quote(str(project_id), ''), iid)
         response = self._api_request('PUT', path, fields=kwargs)
         if response.status == 200:
@@ -588,7 +613,7 @@ class GitLab(Forge):
         _unexpected_status(path, response)
 
     def _post_merge_request_note(self, project_id, iid, kwargs):
-        path = 'projects/%s/merge_requests/%s/notes' % (
+        path = 'projects/{}/merge_requests/{}/notes'.format(
             urlutils.quote(str(project_id), ''), iid)
         response = self._api_request('POST', path, fields=kwargs)
         if response.status == 201:
@@ -657,7 +682,7 @@ class GitLab(Forge):
         if project is None:
             project = base_project['path']
         try:
-            target_project = self._get_project('%s/%s' % (owner, project))
+            target_project = self._get_project('{}/{}'.format(owner, project))
         except NoSuchProject:
             target_project = self.fork_project(
                 base_project['path_with_namespace'], owner=owner)
@@ -684,9 +709,9 @@ class GitLab(Forge):
         if project is None:
             project = self._get_project(base_project)['path']
         try:
-            target_project = self._get_project('%s/%s' % (owner, project))
+            target_project = self._get_project('{}/{}'.format(owner, project))
         except NoSuchProject:
-            raise errors.NotBranchError('%s/%s/%s' % (self.base_url, owner, project))
+            raise errors.NotBranchError('{}/{}/{}'.format(self.base_url, owner, project))
         if preferred_schemes is None:
             preferred_schemes = ['git+ssh']
         for scheme in preferred_schemes:
@@ -699,7 +724,8 @@ class GitLab(Forge):
         else:
             raise AssertionError
         return _mod_branch.Branch.open(
-            gitlab_url_to_bzr_url(gitlab_url, name))
+            gitlab_url_to_bzr_url(gitlab_url, name),
+            possible_transports=[base_branch.user_transport])
 
     def get_proposer(self, source_branch, target_branch):
         return GitlabMergeProposalBuilder(self, source_branch, target_branch)
@@ -779,7 +805,7 @@ class GitLab(Forge):
             return instance
         try:
             resp = transport.request(
-                'GET', 'https://%s/api/v4/projects/%s' % (host, urlutils.quote(str(project), '')))
+                'GET', 'https://{}/api/v4/projects/{}'.format(host, urlutils.quote(str(project), '')))
         except errors.UnexpectedHttpStatus as e:
             raise UnsupportedForge(url)
         except errors.RedirectRequested:
@@ -808,7 +834,7 @@ class GitLab(Forge):
         for mp in self._list_merge_requests(author=author, state=state):
             yield GitLabMergeProposal(self, mp)
 
-    def iter_my_forks(self, owner=None):
+    def iter_my_forks(self, owner: Optional[str] = None):
         if owner is None:
             owner = self.get_current_user()
         for project in self._list_projects(owner=owner):
@@ -817,7 +843,7 @@ class GitLab(Forge):
                 continue
             yield project['path_with_namespace']
 
-    def get_proposal_by_url(self, url):
+    def get_proposal_by_url(self, url: str) -> GitLabMergeProposal:
         try:
             (host, project, merge_id) = parse_gitlab_merge_request_url(url)
         except NotGitLabUrl:
@@ -873,7 +899,8 @@ class GitlabMergeProposalBuilder(MergeProposalBuilder):
     def create_proposal(self, description, title=None, reviewers=None,
                         labels=None, prerequisite_branch=None,
                         commit_message=None, work_in_progress=False,
-                        allow_collaboration=False):
+                        allow_collaboration=False,
+                        delete_source_after_merge: Optional[bool] = None):
         """Perform the submission."""
         # https://docs.gitlab.com/ee/api/merge_requests.html#create-mr
         if prerequisite_branch is not None:
@@ -881,7 +908,6 @@ class GitlabMergeProposalBuilder(MergeProposalBuilder):
         # Note that commit_message is ignored, since Gitlab doesn't support it.
         source_project = self.gl._get_project(self.source_project_name)
         target_project = self.gl._get_project(self.target_project_name)
-        # TODO(jelmer): Allow setting title explicitly
         if title is None:
             title = determine_title(description)
         if work_in_progress:
@@ -896,6 +922,8 @@ class GitlabMergeProposalBuilder(MergeProposalBuilder):
             'target_branch_name': self.target_branch_name,
             'description': description,
             'allow_collaboration': allow_collaboration}
+        if delete_source_after_merge is not None:
+            kwargs['should_remove_source_branch'] = delete_source_after_merge
         if labels:
             kwargs['labels'] = ','.join(labels)
         if reviewers:
