@@ -263,8 +263,7 @@ class TestCommit(TestCaseWithWorkingTree):
             return
         committed_id = tree.commit('foo', local=True)
         self.assertFalse(master.repository.has_revision(committed_id))
-        self.assertEqual(_mod_revision.NULL_REVISION,
-                         (_mod_revision.ensure_null(master.last_revision())))
+        self.assertEqual(_mod_revision.NULL_REVISION, master.last_revision())
 
     def test_record_initial_ghost(self):
         """The working tree needs to record ghosts during commit."""
@@ -446,7 +445,7 @@ class TestCommit(TestCaseWithWorkingTree):
 class TestCommitProgress(TestCaseWithWorkingTree):
 
     def setUp(self):
-        super(TestCommitProgress, self).setUp()
+        super().setUp()
         ui.ui_factory = ProgressRecordingUIFactory()
 
     def test_commit_progress_steps(self):
@@ -461,7 +460,7 @@ class TestCommitProgress(TestCaseWithWorkingTree):
         self.build_tree(['a', 'b', 'c'])
         tree.add(['a', 'b', 'c'])
         tree.commit('first post')
-        with open('b', 'wt') as f:
+        with open('b', 'w') as f:
             f.write('new content')
         # set a progress bar that captures the calls so we can see what is
         # emitted
